#vider la mmoire
rm(list=ls())

#librairie
library(xlsx)

#charger
donnees <- read.xlsx("Low_Birth_Weight_Data.xlsx",sheetIndex = 1, header=TRUE)

#premieres lignes
print(head(donnees))

#description
str(donnees)

#modle : LOW vs. l'ensemble des variables explicatives
modele <- glm(LOW ~ ., data = donnees, family = binomial)

#test du rapport de vraisemblance
chi2 <- modele$null.deviance - modele$deviance
print(chi2)

#ddl
ddl <- modele$df.null - modele$df.residual
print(ddl)

#p-value < 0.05, modle globalement significatif
print(pchisq(chi2,ddl,lower.tail=FALSE))

#rsultats dtaills - 3 coefficients (de variables) prsentent une p-value < 0.05
print(summary(modele))

#probabilits d'affectation
scores <- predict(modele, newdata = donnees, type = "response")
print(summary(scores))

#boxplot des scores
boxplot(scores)

#afficher les boxplot selon les classes
boxplot(scores ~ donnees$LOW)

#**********************
#diagramme de fiabilit
#**********************

#groupes de dcoupage
g1 <- cut(scores,breaks=seq(from=0.0, to=1.0, by=0.25),include.lowest=T)
print(table(g1))

#moyenne des probabilits par groupe
moy.scores <- tapply(scores,g1,mean)
print(moy.scores)

#proportion des positifs par groupe
prop.pos <- apply(table(g1,donnees$LOW),1,function(x){x[2]/sum(x)})
print(prop.pos)

#diagramme de fiabilit
plot(moy.scores,prop.pos,main="Diagramme de fiabilit",type="b",xlim=c(0,1),ylim=c(0,1))
abline(a=0,b=1)

#*************************
#Test de Hosmer & Lemeshow
#*************************

#groupes avec les dciles
g2 <- cut(scores,breaks=quantile(scores,probs=seq(0.0,1.0,0.1)),include.lowest=TRUE)
print(table(g2))

#somme des scores par groupe
sum.pos.scores <- tapply(scores,g2,sum)
print(sum.pos.scores)

#n_g - somme des scores positifs
sum.neg.scores <- table(g2)-sum.pos.scores
print(sum.neg.scores)

#effectifs neg/pos par groupe
effectifs.neg.pos <- table(g2,donnees$LOW)
print(effectifs.neg.pos)

#pour les ngatifs
C1 <- sum((effectifs.neg.pos[,1]-sum.neg.scores)^2/sum.neg.scores)

#pour les positifs
C2 <- sum((effectifs.neg.pos[,2]-sum.pos.scores)^2/sum.pos.scores)

#Statistique de Hosmer & Lemeshow
HL <- C1 + C2
print(HL)

#et p-value
#p-value > 0.05, les scores calculs sont compatibles avec les prop. observes des classes
#le modle semble convenir
print(pchisq(HL,10-2,lower.tail=FALSE))

#package spcialis
library(generalhoslem)

#appel de la fonction
print(generalhoslem::logitgof(donnees$LOW,scores))

#autre package
library(ResourceSelection)

#appel de la fonction
ResourceSelection::hoslem.test(unclass(donnees$LOW)-1,scores)
